@@ -150,6 +150,7 @@ class Model(torch.nn.Module):
                 num_workers=0,
                 use_amp=False,
                 accum_grad_steps=1,
+                sampler=None,
                 **dl_kwargs
                 ):
         """
@@ -187,6 +188,8 @@ class Model(torch.nn.Module):
 
         * `accum_grad_steps` (int, default=1): How many steps to update the model parameters
 
+        * `sampler` (Sampler, default=None): Sampler for training
+
         * `**dl_kwargs`: Extra keyword arguments for DataLoader
         """
 
@@ -228,16 +231,17 @@ class Model(torch.nn.Module):
 
         if sample_weight is not None:
             assert len(sample_weight) == len(train_set)
+            assert sampler is None
             sampler = WeightedRandomSampler(sample_weight, len(sample_weight))
-            shuffle = None
-        else:
-            sampler = None
         
         num_workers = _get_num_workers(num_workers)
 
         if validation_batch_size is None:
             validation_batch_size = batch_size
 
+        if sampler is not None:
+            shuffle = False
+
         train_loader = DataLoader(train_set, shuffle=shuffle, sampler=sampler, batch_size=batch_size, num_workers=num_workers, **dl_kwargs)
         val_loader = DataLoader(val_set, shuffle=False, batch_size=validation_batch_size, num_workers=num_workers, **dl_kwargs) if has_val else None
 
@@ -292,11 +296,11 @@ class Model(torch.nn.Module):
             with autocast(use_amp, device):
                 o = self(*batch)
                 o = activation(o)
-                outputs.append(o)
+                outputs.append(o.cpu())
 
         outputs = torch.cat(outputs, dim=0)
 
-        return outputs.cpu().numpy() if output_numpy else outputs
+        return outputs.numpy() if output_numpy else outputs
 
     @torch.no_grad()
     def predict(self, x, batch_size=32, device=None, output_numpy=True, activation=None, num_workers=0, use_amp=False, progress_bar=False, **dl_kwargs):
